==> PhenStat_2.14.0.tar.gz: PhenStat/man/finalModel.Rd <==
\name{finalModel}
\alias{finalModel}
\title{Method "finalModel"}
\description{
    This is an internal function run within MM framework. It completes the final stage of the MM framework, which builds the final model and estimates effects.  
    As an internal function, it doesn't include extensive error testing of inputs. Please use cautiously if calling directly.  
        
    Works with \code{\linkS4class{PhenTestResult}} object created by \code{\link{startModel}} function. 
    The creation of MM final model is based on the significance of different fixed effects, depVariable and equation values 
    stored in \code{\linkS4class{PhenTestResult}} object.
}
\usage{
    finalModel(phenTestResult, 
				outputMessages = TRUE)
}
\arguments{   
    \item{phenTestResult}{instance of the \code{\linkS4class{PhenTestResult}} class that comes from the function \code{\link{testDataset}}; mandatory argument}
    \item{outputMessages}{flag: "FALSE" value to suppress output messages; "TRUE" value to show output messages; default value TRUE}   

}
\value{
    Returns results stored in instance of the \code{\linkS4class{PhenTestResult}} class
}

\references{
    Karp N, Melvin D, Sanger Mouse Genetics Project, Mott R (2012): Robust and Sensitive Analysis of Mouse Knockout Phenotypes. \emph{PLoS ONE} \bold{7}(12): e52410. doi:10.1371/journal.pone.0052410
    
    West B, Welch K, Galecki A (2007): Linear Mixed Models: A practical guide using statistical software  \emph{New York: Chapman & Hall/CRC} 353 p.
}
\author{Natalja Kurbatova, Natasha Karp, Jeremy Mason}
\seealso{\code{\linkS4class{PhenTestResult}} and \code{\link{testDataset}}}
\examples{
    file <- system.file("extdata", "test1.csv", package="PhenStat")
    test <- PhenStat:::PhenList(dataset=read.csv(file,na.strings = '-'),
            testGenotype="Sparc/Sparc")
    # when "testDataset" function's argument "callAll" is set to FALSE 
    # only "startModel" function is called - the first step of MM framework
    result <- PhenStat:::testDataset(test,
            depVariable="Lean.Mass",
            equation="withoutWeight",
            callAll=FALSE) 
    # print out formula that has been created
    # result$model.formula.genotype
    # print out batch effect's significance 
    # result$model.effect.batch
    # change the model
    # result <- PhenStat:::testDataset(test,
    #        depVariable="Lean.Mass",
    #        equation="withWeight",
    #        callAll=FALSE) 
    # print out new formula
    #result$model.formula.genotype
    # run the final model fitting when statisfied with the model
    result <- PhenStat:::finalModel(result)
}

==> PhenStat_2.43.0.tar.gz: PhenStat/man/finalModel.Rd <==
\name{finalModel}
\alias{finalModel}
\title{Method "finalModel"}
\description{
    This is an internal function run within MM framework. It completes the final stage of the MM framework, which builds the final model and estimates effects.
    As an internal function, it doesn't include extensive error testing of inputs. Please use cautiously if calling directly.

    Works with \code{\linkS4class{PhenTestResult}} object created by \code{\link{startModel}} function.
    The creation of MM final model is based on the significance of different fixed effects, depVariable and equation values
    stored in \code{\linkS4class{PhenTestResult}} object.
}
\usage{
    finalModel(phenTestResult,
				outputMessages = TRUE,
				modelWeight = NULL)
}
\arguments{
    \item{phenTestResult}{instance of the \code{\linkS4class{PhenTestResult}} class that comes from the function \code{\link{testDataset}}; mandatory argument}
    \item{outputMessages}{flag: "FALSE" value to suppress output messages; "TRUE" value to show output messages; default value TRUE}
    \item{modelWeight}{
    A vector of positive values for weights mainly used for appliying windowing to the data
    }

}
\value{
    Returns results stored in instance of the \code{\linkS4class{PhenTestResult}} class
}

\references{
    Karp N, Melvin D, Sanger Mouse Genetics Project, Mott R (2012): Robust and Sensitive Analysis of Mouse Knockout Phenotypes. \emph{PLoS ONE} \bold{7}(12): e52410. doi:10.1371/journal.pone.0052410

    West B, Welch K, Galecki A (2007): Linear Mixed Models: A practical guide using statistical software  \emph{New York: Chapman & Hall/CRC} 353 p.
}
\author{Natalja Kurbatova, Natasha Karp, Jeremy Mason}
\seealso{\code{\linkS4class{PhenTestResult}} and \code{\link{testDataset}}}
\examples{
    file <- system.file("extdata", "test1.csv", package="PhenStat")
    test <- PhenStat:::PhenList(dataset=read.csv(file,na.strings = '-'),
            testGenotype="Sparc/Sparc")
    # when "testDataset" function's argument "callAll" is set to FALSE
    # only "startModel" function is called - the first step of MM framework
    result <- PhenStat:::testDataset(test,
            depVariable="Lean.Mass",
            equation="withoutWeight",
            callAll=FALSE)
    # print out formula that has been created
    # result$model.formula.genotype
    # print out batch effect's significance
    # result$model.effect.batch
    # change the model
    # result <- PhenStat:::testDataset(test,
    #        depVariable="Lean.Mass",
    #        equation="withWeight",
    #        callAll=FALSE)
    # print out new formula
    #result$model.formula.genotype
    # run the final model fitting when statisfied with the model
    result <- PhenStat:::finalModel(result)
}
